@@ -5,7 +5,7 @@ from django.utils.translation import pgettext_lazy
 
 
 __all__ = (
-    'create_types_field', 'create_division_field',
+    'create_types_field', 'create_division_field', 'codes_indexes',
     'CodesDefinableMixin', 'GroupingMixin', 'NamedMixin',
 )
 
@@ -31,16 +31,21 @@ def create_division_field(**kw):
     )
 
 
+
+def codes_indexes():
+    return [
+        GinIndex(
+            name='%(app_label)s_%(class)s_codes_idx',
+            fields=['codes'],
+            opclasses=('jsonb_ops',)
+        ),
+    ]
+
+
 class CodesDefinableMixin(models.Model):
     class Meta:
         abstract = True
-        indexes = (
-            GinIndex(
-                name='%(app_label)s_%(class)s_codes_index',
-                fields=['codes'],
-                opclasses=('jsonb_ops',)
-            ),
-        )
+        indexes = codes_indexes()
 
     codes = models.JSONField(
         verbose_name=pgettext_lazy('wcd_geo_db', 'Codes'),
