@@ -1,4 +1,4 @@
-from typing import TypeVar
+from typing import Any, Dict, Optional, Sequence, Tuple, TypeVar
 from wcd_geo_db.modules.code_seeker import CodeSeekerRegistry, query
 
 
@@ -21,8 +21,11 @@ class CodeSeekingClientMixin:
 
         self.code_seeker_registry = code_seeker_registry
 
-    def _filter_codes(self, qs: QT, codes: query.CodeSeekSeq) -> QT:
-        return qs.seek_codes(
-            self.code_seeker_registry, codes,
-            warning_context=f'{self.__class__} client\'s registry'
-        )
+    def _get_codes_filter(
+        self, codes:  Optional[query.CodeSeekSeq] = None
+    ) -> query.CodesFilter:
+        return {
+            'registry': self.code_seeker_registry,
+            'codes': codes,
+            'warning_context': f'{self.__class__} client\'s registry'
+        }
