@@ -26,7 +26,7 @@ class CodeSeeker:
 
     def Q(self, value: Any, field_name: Optional[str] = None) -> models.Q:
         return models.Q(**{
-            f'{field_name or self.field_name}__{self.name}': value
+            f'{field_name or self.field_name}__contains': {self.name: value}
         })
 
     def eq(self, a: Any, b: Any) -> bool:
