@@ -9,6 +9,7 @@ __all__ = 'DivisionItem', 'DivisionTranslationItem',
 
 class DivisionItem(TypedDict):
     code: Tuple[str, Any]
+    codes: List[Tuple[str, Any]]
     path: List[Tuple[str, Any]]
     name: Optional[str]
     types: List[DivisionType]
@@ -16,4 +17,6 @@ class DivisionItem(TypedDict):
 
 
 class DivisionTranslationItem(TypedDict):
+    code: Tuple[str, Any]
     name: Optional[str]
+    synonyms: Optional[str]
